@@ -1,2 +1,2 @@
-import ServerObjects
+import SmsObjects
 from .client import SmsClient
